#ifndef XMEM_CONFIG_H_
#define XMEM_CONFIG_H_

#define XPAR_PSU_DDR_1_BASEADDRESS 0x800000000
#define XPAR_PSU_DDR_1_HIGHADDRESS 0x87fffffff
#define XPAR_PSU_DDR_0_BASEADDRESS 0x0
#define XPAR_PSU_DDR_0_HIGHADDRESS 0x7fefffff
#define XPAR_PSU_QSPI_LINEAR_0_BASEADDRESS 0xc0000000
#define XPAR_PSU_QSPI_LINEAR_0_HIGHADDRESS 0xdfffffff
#define XPAR_PSU_OCM_0_BASEADDRESS 0xfffc0000
#define XPAR_PSU_OCM_0_HIGHADDRESS 0xffffffff

#endif